@@ -12,7 +12,7 @@ A simple python wrapper for Google's `Firebase Cloud Storage REST API`_
 	https://firebase.google.com/docs/reference/rest/storage/rest
 """
 
-import requests
+import datetime
 from gcloud import storage
 from urllib.parse import quote
 
@@ -131,7 +131,7 @@ class Storage:
 
 			return request_object.json()
 
-	def delete(self, name, token):
+	def delete(self, token=None):
 		""" Delete file from storage.
 
 		| For more details:
@@ -145,17 +145,23 @@ class Storage:
 			https://firebase.google.com/docs/storage/web/delete-files#delete_a_file
 
 
-		:type name: str
-		:param name: Cloud path to file.
-
 		:type token: str
-		:param token: Firebase Auth User ID Token
+		:param token: (Optional) Firebase Auth User ID Token, defaults 
+			to :data:`None`.
 		"""
 
+		# reset path
+		path = self.path
+		self.path = None
+
+		# remove leading backlash
+		if path.startswith('/'):
+			path = path[1:]
+
 		if self.credentials:
-			self.bucket.delete_blob(name)
+			self.bucket.delete_blob(path)
 		else:
-			request_ref = self.storage_bucket + "/o?name={0}".format(name)
+			request_ref = self.storage_bucket + "/o?name={0}".format(path)
 
 			if token:
 				headers = {"Authorization": "Firebase " + token}
@@ -203,7 +209,7 @@ class Storage:
 
 		elif token:
 			headers = {"Authorization": "Firebase " + token}
-			r = requests.get(self.get_url(token), stream=True, headers=headers)
+			r = self.requests.get(self.get_url(token), stream=True, headers=headers)
 
 			if r.status_code == 200:
 				with open(filename, 'wb') as f:
@@ -211,33 +217,53 @@ class Storage:
 						f.write(chunk)
 
 		else:
-			r = requests.get(self.get_url(token), stream=True)
+			r = self.requests.get(self.get_url(token), stream=True)
 
 			if r.status_code == 200:
 				with open(filename, 'wb') as f:
 					for chunk in r:
 						f.write(chunk)
 
-	def get_url(self, token):
+	def get_url(self, token=None, expiration_hour=24):
 		""" Fetches URL for file.
 
 
 		:type token: str
-		:param token: Firebase Auth User ID Token.
+		:param token: (Optional) Firebase Auth User ID Token, defaults
+			to :data:`None`.
 
+		:type expiration_hour: int
+		:param expiration_hour: (Optional) time in ``hour`` for URL to
+			expire after, defaults to 24 hours. Works only for links
+			generated with admin credentials.
 
 		:return: URL for the file.
 		:rtype: str
 		"""
 
+		# reset path
 		path = self.path
 		self.path = None
 
+		# remove leading backlash
 		if path.startswith('/'):
 			path = path[1:]
 
-		if token:
-			return "{0}/o/{1}?alt=media&token={2}".format(self.storage_bucket, quote(path, safe=''), token)
+		if self.credentials:
+			blob = self.bucket.get_blob(path)
+			if blob:
+				return blob.generate_signed_url(datetime.timedelta(hours=expiration_hour), method='GET')
+
+		elif token:
+
+			# retrieve download tokens first
+			headers = {"Authorization": "Bearer " + token}
+			request_ref = "{0}/o/{1}".format(self.storage_bucket, quote(path, safe=''))
+			request_object = self.requests.get(request_ref, headers=headers)
+
+			raise_detailed_error(request_object)
+
+			return "{0}/o/{1}?alt=media&token={2}".format(self.storage_bucket, quote(path, safe=''), request_object.json()['downloadTokens'])
 
 		return "{0}/o/{1}?alt=media".format(self.storage_bucket, quote(path, safe=''))
 
